BatchDeleteBuildsOutput class

Constructors

BatchDeleteBuildsOutput({List<String>? buildsDeleted, List<BuildNotDeleted>? buildsNotDeleted})
BatchDeleteBuildsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

buildsDeleted → List<String>?
The IDs of the builds that were successfully deleted.
final
buildsNotDeleted → List<BuildNotDeleted>?
Information about any builds that could not be successfully deleted.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited