CodeCoverage class

Contains code coverage report information.

Line coverage measures how many statements your tests cover. A statement is a single instruction, not including comments, conditionals, etc.

Branch coverage determines if your tests cover every possible branch of a control structure, such as an if or case statement.

Constructors

CodeCoverage({double? branchCoveragePercentage, int? branchesCovered, int? branchesMissed, DateTime? expired, String? filePath, String? id, double? lineCoveragePercentage, int? linesCovered, int? linesMissed, String? reportARN})
CodeCoverage.fromJson(Map<String, dynamic> json)
factory

Properties

branchCoveragePercentage → double?
The percentage of branches that are covered by your tests.
final
branchesCovered → int?
The number of conditional branches that are covered by your tests.
final
branchesMissed → int?
The number of conditional branches that are not covered by your tests.
final
expired → DateTime?
The date and time that the tests were run.
final
filePath → String?
The path of the test report file.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
The identifier of the code coverage report.
final
lineCoveragePercentage → double?
The percentage of lines that are covered by your tests.
final
linesCovered → int?
The number of lines that are covered by your tests.
final
linesMissed → int?
The number of lines that are not covered by your tests.
final
reportARN → String?
The ARN of the report.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited