LogsLocation class

Information about build logs in Amazon CloudWatch Logs.

Constructors

LogsLocation({CloudWatchLogsConfig? cloudWatchLogs, String? cloudWatchLogsArn, String? deepLink, String? groupName, String? s3DeepLink, S3LogsConfig? s3Logs, String? s3LogsArn, String? streamName})
LogsLocation.fromJson(Map<String, dynamic> json)
factory

Properties

cloudWatchLogs → CloudWatchLogsConfig?
Information about Amazon CloudWatch Logs for a build project.
final
cloudWatchLogsArn → String?
The ARN of Amazon CloudWatch Logs for a build project. Its format is arn:${Partition}:logs:${Region}:${Account}:log-group:${LogGroupName}:log-stream:${LogStreamName}. For more information, see Resources Defined by Amazon CloudWatch Logs.
final
The URL to an individual build log in Amazon CloudWatch Logs.
final
groupName → String?
The name of the Amazon CloudWatch Logs group for the build logs.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The URL to a build log in an S3 bucket.
final
s3Logs → S3LogsConfig?
Information about S3 logs for a build project.
final
s3LogsArn → String?
The ARN of S3 logs for a build project. Its format is arn:${Partition}:s3:::${BucketName}/${ObjectName}. For more information, see Resources Defined by Amazon S3.
final
streamName → String?
The name of the Amazon CloudWatch Logs stream for the build logs.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited