VpcConfig class

Information about the VPC configuration that AWS CodeBuild accesses.

Constructors

VpcConfig({List<String>? securityGroupIds, List<String>? subnets, String? vpcId})
VpcConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityGroupIds → List<String>?
A list of one or more security groups IDs in your Amazon VPC.
final
subnets → List<String>?
A list of one or more subnet IDs in your Amazon VPC.
final
vpcId → String?
The ID of the Amazon VPC.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited